package org.apache.bcel.classfile;

import java.io.IOException;
import java.io.DataOutputStream;

public class ArrayElementValue extends ElementValue
{
    private final ElementValue[] elementValues;
    
    public ArrayElementValue(final int type, final ElementValue[] datums, final ConstantPool cpool) {
        super(type, cpool);
        if (type != 91) {
            throw new IllegalArgumentException("Only element values of type array can be built with this ctor - type specified: " + type);
        }
        this.elementValues = datums;
    }
    
    @Override
    public void dump(final DataOutputStream dos) throws IOException {
        dos.writeByte(super.getType());
        dos.writeShort(this.elementValues.length);
        for (final ElementValue evalue : this.elementValues) {
            evalue.dump(dos);
        }
    }
    
    public ElementValue[] getElementValuesArray() {
        return this.elementValues;
    }
    
    public int getElementValuesArraySize() {
        return this.elementValues.length;
    }
    
    @Override
    public String stringifyValue() {
        final StringBuilder sb = new StringBuilder();
        sb.append("[");
        for (int i = 0; i < this.elementValues.length; ++i) {
            sb.append(this.elementValues[i].stringifyValue());
            if (i + 1 < this.elementValues.length) {
                sb.append(",");
            }
        }
        sb.append("]");
        return sb.toString();
    }
    
    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        sb.append("{");
        for (int i = 0; i < this.elementValues.length; ++i) {
            sb.append(this.elementValues[i]);
            if (i + 1 < this.elementValues.length) {
                sb.append(",");
            }
        }
        sb.append("}");
        return sb.toString();
    }
}
